@@ -1,13 +1,14 @@
+# SPDX-FileCopyrightText: 2025 QinHan
+# SPDX-License-Identifier: MPL-2.0
 import asyncio
 from dataclasses import dataclass
 from typing import Self, Literal, Set, Dict, List, Tuple
 
-from bs4 import BeautifulSoup, NavigableString, Tag, Comment
+from bs4 import BeautifulSoup, NavigableString, Comment
 
 from docutranslate.agents.segments_agent import SegmentsTranslateAgentConfig, SegmentsTranslateAgent
 from docutranslate.ir.document import Document
-from docutranslate.translator.ai_translator.base import AiTranslatorConfig
-from docutranslate.translator.base import Translator
+from docutranslate.translator.ai_translator.base import AiTranslatorConfig, AiTranslator
 
 # --- 规则定义 ---
 
@@ -16,16 +17,16 @@ from docutranslate.translator.base import Translator
 # 在预处理阶段，这些标签及其所有子元素将被直接从文档中移除，以确保它们不会被意外修改。
 NON_TRANSLATABLE_TAGS: Set[str] = {
     'script',  # JavaScript代码
-    'style',   # CSS样式
-    'pre',     # 预格式化文本，通常用于代码块
-    'code',    # 行内代码
-    'kbd',     # 键盘输入
-    'samp',    # 示例输出
-    'var',     # 变量
-    'noscript',# script未启用时的内容
-    'meta',    # 元数据
-    'link',    # 外部资源链接
-    'head',    # 文档头部，通常不包含可见的可翻译内容
+    'style',  # CSS样式
+    'pre',  # 预格式化文本，通常用于代码块
+    'code',  # 行内代码
+    'kbd',  # 键盘输入
+    'samp',  # 示例输出
+    'var',  # 变量
+    'noscript',  # script未启用时的内容
+    'meta',  # 元数据
+    'link',  # 外部资源链接
+    'head',  # 文档头部，通常不包含可见的可翻译内容
 }
 
 # 2. 可翻译标签（白名单）
@@ -73,7 +74,7 @@ class HtmlTranslatorConfig(AiTranslatorConfig):
     separator: str = " "  # HTML中用空格作为默认分隔符可能更合适
 
 
-class HtmlTranslator(Translator):
+class HtmlTranslator(AiTranslator):
     """
     一个用于翻译 HTML 文件内容的翻译器。
     它采用黑白名单结合的策略，以最大程度地保留页面样式和功能：
@@ -86,20 +87,24 @@ class HtmlTranslator(Translator):
     def __init__(self, config: HtmlTranslatorConfig):
         super().__init__(config=config)
         self.chunk_size = config.chunk_size
-        agent_config = SegmentsTranslateAgentConfig(
-            custom_prompt=config.custom_prompt,
-            to_lang=config.to_lang,
-            baseurl=config.base_url,
-            key=config.api_key,
-            model_id=config.model_id,
-            system_prompt=None,
-            temperature=config.temperature,
-            thinking=config.thinking,
-            max_concurrent=config.concurrent,
-            timeout=config.timeout,
-            logger=self.logger
-        )
-        self.translate_agent = SegmentsTranslateAgent(agent_config)
+        self.translate_agent = None
+        if not self.skip_translate:
+            agent_config = SegmentsTranslateAgentConfig(
+                custom_prompt=config.custom_prompt,
+                to_lang=config.to_lang,
+                base_url=config.base_url,
+                api_key=config.api_key,
+                model_id=config.model_id,
+                temperature=config.temperature,
+                thinking=config.thinking,
+                concurrent=config.concurrent,
+                timeout=config.timeout,
+                logger=self.logger,
+                glossary_dict=config.glossary_dict,
+                retry=config.retry,
+                system_proxy_enable=config.system_proxy_enable
+            )
+            self.translate_agent = SegmentsTranslateAgent(agent_config)
         self.insert_mode = config.insert_mode
         self.separator = config.separator
 
@@ -133,7 +138,7 @@ class HtmlTranslator(Translator):
 
             # --- 2b. 翻译安全标签内的安全属性 ---
             attributes_to_check = SAFE_ATTRIBUTES.get(tag.name, []) + SAFE_ATTRIBUTES.get('*', [])
-            for attr in set(attributes_to_check): # 使用set去重
+            for attr in set(attributes_to_check):  # 使用set去重
                 if tag.has_attr(attr) and tag[attr].strip():
                     value = tag[attr]
                     translatable_items.append({'type': 'attribute', 'tag': tag, 'attribute': attr})
@@ -145,6 +150,7 @@ class HtmlTranslator(Translator):
                          translated_texts: list[str], original_texts: list[str]) -> bytes:
         """
         将翻译后的文本写回到BeautifulSoup对象中对应的节点或属性，并返回最终的HTML字节流。
+        【版本 3.0: 修正了对HTML分隔符的支持】
         """
         if len(translatable_items) != len(translated_texts):
             self.logger.error("翻译前后的文本片段数量不匹配 (%d vs %d)，跳过写入操作以防损坏文件。",
@@ -155,36 +161,59 @@ class HtmlTranslator(Translator):
             translated_text = translated_texts[i]
             original_text = original_texts[i]
 
-            new_content = ""
-            if self.insert_mode == "replace":
-                if item['type'] == 'node':
-                    # 对于文本节点，保留原文前后的空白字符，这对维持内联元素的间距至关重要。
-                    leading_space = original_text[:len(original_text) - len(original_text.lstrip())]
-                    trailing_space = original_text[len(original_text.rstrip()):]
-                    new_content = leading_space + translated_text + trailing_space
-                else:  # 属性
-                    new_content = translated_text
-
-            elif self.insert_mode == "append":
-                new_content = original_text + self.separator + translated_text
-            elif self.insert_mode == "prepend":
-                new_content = translated_text + self.separator + original_text
-            else:
-                self.logger.error(f"不正确的HtmlTranslatorConfig参数: insert_mode='{self.insert_mode}'")
-                new_content = original_text # 出错时恢复原文
-
-            # 根据类型将内容写回
             if item['type'] == 'node':
                 node = item['object']
-                # 检查节点是否仍然在解析树中，以防在处理过程中被移动或删除
-                if node.parent:
-                    node.replace_with(NavigableString(new_content))
+                if not node.parent:  # 确保节点仍然在树中
+                    continue
+
+                # --- 构造包含HTML的新内容字符串 ---
+                new_content_str = ""
+                if self.insert_mode == "replace":
+                    leading_space = original_text[:len(original_text) - len(original_text.lstrip())]
+                    trailing_space = original_text[len(original_text.rstrip()):]
+                    new_content_str = leading_space + translated_text + trailing_space
+                elif self.insert_mode == "append":
+                    new_content_str = original_text + self.separator + translated_text
+                elif self.insert_mode == "prepend":
+                    new_content_str = translated_text + self.separator + original_text
+                else:
+                    self.logger.error(f"不正确的HtmlTranslatorConfig参数: insert_mode='{self.insert_mode}'")
+                    new_content_str = original_text
+
+                # --- 核心修改：正确地将HTML字符串片段插入DOM ---
+                # 1. 使用一个临时的父标签（如此处的'div'）来解析HTML片段，
+                #    这是在BeautifulSoup中处理片段的标准做法，避免了自动添加<html><body>。
+                temp_soup = BeautifulSoup(f"<div>{new_content_str}</div>", 'html.parser')
+                new_elements = temp_soup.div.contents
+
+                # 2. 将解析出的新元素（可能是文本节点和<br>标签的混合）
+                #    以相反的顺序插入到原始节点之后。这样做可以保持它们的原始顺序。
+                for element in reversed(new_elements):
+                    node.insert_after(element)
+
+                # 3. 移除原始的文本节点
+                node.decompose()
+
             elif item['type'] == 'attribute':
+                # --- 属性逻辑保持不变，因为属性值不支持HTML ---
                 tag = item['tag']
                 attr = item['attribute']
-                tag[attr] = new_content
+                new_attr_value = ""
+
+                # 在属性值中，<br>将被视为普通文本，这是正确的行为
+                separator_for_attr = self.separator.replace('<br>', ' ').replace('<br/>', ' ')
+
+                if self.insert_mode == "replace":
+                    new_attr_value = translated_text
+                elif self.insert_mode == "append":
+                    new_attr_value = original_text + separator_for_attr + translated_text
+                elif self.insert_mode == "prepend":
+                    new_attr_value = translated_text + separator_for_attr + original_text
+                else:
+                    new_attr_value = original_text
+
+                tag[attr] = new_attr_value.strip()
 
-        # 将修改后的BeautifulSoup对象编码为utf-8字节流
         return soup.encode('utf-8')
 
     def translate(self, document: Document) -> Self:
@@ -198,7 +227,14 @@ class HtmlTranslator(Translator):
             document.content = soup.encode('utf-8')
             return self
 
-        translated_texts = self.translate_agent.send_segments(original_texts, self.chunk_size)
+        if self.glossary_agent:
+            self.glossary_dict_gen = self.glossary_agent.send_segments(original_texts, self.chunk_size)
+            if self.translate_agent:
+                self.translate_agent.update_glossary_dict(self.glossary_dict_gen)
+        if self.translate_agent:
+            translated_texts = self.translate_agent.send_segments(original_texts, self.chunk_size)
+        else:
+            translated_texts = original_texts
         document.content = self._after_translate(soup, translatable_items, translated_texts, original_texts)
         return self
 
@@ -213,8 +249,15 @@ class HtmlTranslator(Translator):
             document.content = await asyncio.to_thread(soup.encode, 'utf-8')
             return self
 
-        translated_texts = await self.translate_agent.send_segments_async(original_texts, self.chunk_size)
+        if self.glossary_agent:
+            self.glossary_dict_gen = await self.glossary_agent.send_segments_async(original_texts, self.chunk_size)
+            if self.translate_agent:
+                self.translate_agent.update_glossary_dict(self.glossary_dict_gen)
+        if self.translate_agent:
+            translated_texts = await self.translate_agent.send_segments_async(original_texts, self.chunk_size)
+        else:
+            translated_texts = original_texts
         document.content = await asyncio.to_thread(
             self._after_translate, soup, translatable_items, translated_texts, original_texts
         )
-        return self
\ No newline at end of file
+        return self
